This is an automated email from the ASF dual-hosted git repository.

mbien pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/netbeans.git


The following commit(s) were added to refs/heads/master by this push:
     new c543b8db95 Fixed javadoc tags
     new 8d16de8d3b Merge pull request #5419 from tbw777/javadocB
c543b8db95 is described below

commit c543b8db952d46b7e52ee8729d1a3060aa000729
Author: Andrey Bruykhov <[email protected]>
AuthorDate: Fri Feb 3 19:08:44 2023 +0300

    Fixed javadoc tags
    
    A part of javadoc sync global superproject
---
 .../modules/apisupport/project/spi/NbModuleProvider.java     |  2 +-
 .../src/org/netbeans/modules/glassfish/common/Installer.java |  2 +-
 .../glassfish/common/nodes/actions/DisableModulesCookie.java |  2 +-
 .../glassfish/common/nodes/actions/EnableModulesCookie.java  |  2 +-
 .../glassfish/common/nodes/actions/UndeployModuleCookie.java |  2 +-
 .../common/nodes/actions/UnregisterResourceCookie.java       |  2 +-
 .../modules/glassfish/common/utils/AdminKeyFile.java         |  6 +++---
 .../netbeans/modules/glassfish/javaee/Hk2StartServer.java    |  2 +-
 .../j2ee/ejbcore/ejb/wizard/MultiTargetChooserPanelGUI.java  |  2 +-
 .../j2ee/ejbcore/ui/logicalview/entries/CallEjbPanel.java    |  2 +-
 .../ddloaders/multiview/web/SunWebJspConfigPropertyNode.java |  2 +-
 .../netbeans/modules/j2ee/sun/share/configbean/Utils.java    |  2 +-
 .../src/org/netbeans/modules/payara/common/Installer.java    |  2 +-
 .../payara/common/nodes/actions/DisableModulesCookie.java    |  2 +-
 .../payara/common/nodes/actions/EnableModulesCookie.java     |  2 +-
 .../payara/common/nodes/actions/UndeployModuleCookie.java    |  2 +-
 .../common/nodes/actions/UnregisterResourceCookie.java       |  2 +-
 .../netbeans/modules/payara/common/utils/AdminKeyFile.java   |  6 +++---
 .../netbeans/modules/payara/jakartaee/Hk2StartServer.java    |  2 +-
 .../src/org/netbeans/modules/tomcat5/util/TomcatUsers.java   |  4 ++--
 .../org/netbeans/modules/csl/spi/DefaultLanguageConfig.java  |  6 ++++--
 .../modules/editor/indent/spi/CodeStylePreferences.java      |  2 +-
 ide/editor.lib/src/org/netbeans/editor/EditorUI.java         |  2 +-
 ide/editor.lib/src/org/netbeans/editor/JumpList.java         |  3 ++-
 .../src/org/netbeans/editor/ext/KeywordMatchGenerator.java   |  2 +-
 .../src/org/netbeans/editor/ext/ToolTipSupport.java          | 12 ++++++------
 .../modules/editor/settings/storage/ProfilesTracker.java     |  2 +-
 .../src/org/netbeans/api/languages/ParserManager.java        |  4 ++--
 ide/o.openidex.util/src/org/openidex/search/SearchGroup.java |  2 +-
 .../modules/xml/schema/completion/EndTagResultItem.java      |  2 +-
 .../modules/xml/schema/completion/TagLastCharResultItem.java |  2 +-
 .../modules/xml/schema/model/impl/AnnotationImplTest.java    |  2 +-
 .../src/org/netbeans/modules/xml/text/api/XMLTextUtils.java  |  2 +-
 .../org/netbeans/modules/xml/text/api/dom/SyntaxElement.java |  2 +-
 .../extensions/soap/impl/SOAPElementFactoryProvider.java     |  2 +-
 .../modules/form/layoutsupport/AbstractLayoutSupport.java    |  2 +-
 .../modules/form/layoutsupport/LayoutSupportManager.java     |  2 +-
 .../modules/j2ee/persistence/provider/ProviderUtil.java      |  4 ++--
 .../editor/java/JavaFormatterArrayInitOrEnumUnitTest.java    |  2 +-
 .../netbeans/modules/editor/java/JavaFormatterUnitTest.java  |  2 +-
 .../modules/editor/java/JavaFormatterUnitTestCase.java       |  2 +-
 .../unit/src/org/netbeans/modules/editor/java/TestUtils.java |  2 +-
 .../modules/editor/java/TypingCompletionUnitTest.java        |  2 +-
 .../src/org/netbeans/modules/java/freeform/JavaActions.java  |  2 +-
 .../netbeans/modules/java/source/parsing/JavacParser.java    |  2 +-
 .../installer/wizard/containers/SwingFrameContainer.java     |  2 +-
 .../org/netbeans/modules/php/api/framework/BadgeIcon.java    |  2 +-
 .../src/org/openide/filesystems/localfs/LocalFSTest.java     |  2 +-
 .../o.n.bootstrap/src/org/netbeans/NetigsoFramework.java     |  4 ++--
 .../src/org/openide/loaders/XMLEntityResolverChain.java      |  4 ++--
 platform/openide.util/src/org/openide/xml/XMLUtil.java       |  4 ++--
 .../netbeans/modules/quicksearch/recent/RecentSearches.java  |  2 +-
 .../netbeans/modules/web/clientproject/api/BadgeIcon.java    |  2 +-
 .../src/org/netbeans/modules/websvc/saas/model/Saas.java     |  2 +-
 54 files changed, 73 insertions(+), 70 deletions(-)

diff --git 
a/apisupport/apisupport.project/src/org/netbeans/modules/apisupport/project/spi/NbModuleProvider.java
 
b/apisupport/apisupport.project/src/org/netbeans/modules/apisupport/project/spi/NbModuleProvider.java
index b803ee667f..3275449fd8 100644
--- 
a/apisupport/apisupport.project/src/org/netbeans/modules/apisupport/project/spi/NbModuleProvider.java
+++ 
b/apisupport/apisupport.project/src/org/netbeans/modules/apisupport/project/spi/NbModuleProvider.java
@@ -57,7 +57,7 @@ public interface NbModuleProvider {
     
     /** Returns a relative path to a project's test source directory. 
      * @return relative path to test sources..
-     * @Since 1.56
+     * @since 1.56
      */
     String getTestSourceDirectoryPath();
     /**
diff --git 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/Installer.java
 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/Installer.java
index 6e1741201f..26d39060d1 100644
--- 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/Installer.java
+++ 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/Installer.java
@@ -24,7 +24,7 @@ import org.openide.modules.ModuleInstall;
  * Manages a module's lifecycle. Remember that an installer is optional and
  * often not needed at all.
  *
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public class Installer extends ModuleInstall {
 
diff --git 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/DisableModulesCookie.java
 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/DisableModulesCookie.java
index 755a657cc1..441c1d1c92 100644
--- 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/DisableModulesCookie.java
+++ 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/DisableModulesCookie.java
@@ -29,7 +29,7 @@ import org.openide.nodes.Node;
  *
  * based on UndeployModuleCookie
  * @author Michal Mocnak
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public interface DisableModulesCookie extends Node.Cookie {
     
diff --git 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/EnableModulesCookie.java
 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/EnableModulesCookie.java
index 13e0b4cb9f..fdfac437a4 100644
--- 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/EnableModulesCookie.java
+++ 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/EnableModulesCookie.java
@@ -29,7 +29,7 @@ import org.openide.nodes.Node;
  *
  * based on UndeployModuleCookie
  * @author Michal Mocnak
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public interface EnableModulesCookie extends Node.Cookie {
     
diff --git 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/UndeployModuleCookie.java
 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/UndeployModuleCookie.java
index 14c52e6fce..1cdaa5e790 100644
--- 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/UndeployModuleCookie.java
+++ 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/UndeployModuleCookie.java
@@ -27,7 +27,7 @@ import org.openide.nodes.Node;
 /**
  *
  * @author Michal Mocnak
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public interface UndeployModuleCookie extends Node.Cookie {
     
diff --git 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/UnregisterResourceCookie.java
 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/UnregisterResourceCookie.java
index 6935d025d8..478c12b8ca 100644
--- 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/UnregisterResourceCookie.java
+++ 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/nodes/actions/UnregisterResourceCookie.java
@@ -26,7 +26,7 @@ import org.openide.nodes.Node;
 
 /**
  *
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public interface UnregisterResourceCookie extends Node.Cookie {
     
diff --git 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/utils/AdminKeyFile.java
 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/utils/AdminKeyFile.java
index 16d135e76f..e0fba93429 100644
--- 
a/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/utils/AdminKeyFile.java
+++ 
b/enterprise/glassfish.common/src/org/netbeans/modules/glassfish/common/utils/AdminKeyFile.java
@@ -322,7 +322,7 @@ public class AdminKeyFile {
          * Get value of user <code>String</code> read
          * from <code>admin-keyfile</code>.
          * <p/>
-         * @rerurn Value of user <code>String</code>.
+         * @return Value of user <code>String</code>.
          */
         private String getUser() {
             return user.toString();
@@ -332,7 +332,7 @@ public class AdminKeyFile {
          * Get value of password hash <code>String</code> read
          * from <code>admin-keyfile</code>.
          * <p/>
-         * @rerurn Value of password hash <code>String</code>.
+         * @return Value of password hash <code>String</code>.
          */
         private String getPasswordHash() {
             return hash.toString();
@@ -342,7 +342,7 @@ public class AdminKeyFile {
          * Get value of tool <code>String</code> read
          * from <code>admin-keyfile</code>.
          * <p/>
-         * @rerurn Value of tool <code>String</code>.
+         * @return Value of tool <code>String</code>.
          */
         private String getTool() {
             return tool.toString();
diff --git 
a/enterprise/glassfish.javaee/src/org/netbeans/modules/glassfish/javaee/Hk2StartServer.java
 
b/enterprise/glassfish.javaee/src/org/netbeans/modules/glassfish/javaee/Hk2StartServer.java
index 1da72f5809..78d958ec92 100644
--- 
a/enterprise/glassfish.javaee/src/org/netbeans/modules/glassfish/javaee/Hk2StartServer.java
+++ 
b/enterprise/glassfish.javaee/src/org/netbeans/modules/glassfish/javaee/Hk2StartServer.java
@@ -58,7 +58,7 @@ import org.openide.util.NbBundle;
 /**
  *
  * @author Ludovic Champenois
- * @auther Peter Williams
+ * @author Peter Williams
  * @author vince kraemer
  */
 public class Hk2StartServer extends StartServer implements ProgressObject {
diff --git 
a/enterprise/j2ee.ejbcore/src/org/netbeans/modules/j2ee/ejbcore/ejb/wizard/MultiTargetChooserPanelGUI.java
 
b/enterprise/j2ee.ejbcore/src/org/netbeans/modules/j2ee/ejbcore/ejb/wizard/MultiTargetChooserPanelGUI.java
index 0eb30ac55b..8c3e86aba1 100644
--- 
a/enterprise/j2ee.ejbcore/src/org/netbeans/modules/j2ee/ejbcore/ejb/wizard/MultiTargetChooserPanelGUI.java
+++ 
b/enterprise/j2ee.ejbcore/src/org/netbeans/modules/j2ee/ejbcore/ejb/wizard/MultiTargetChooserPanelGUI.java
@@ -52,7 +52,7 @@ import org.openide.util.RequestProcessor;
  * 
  * @author Petr Hrebejk
  * @author Jesse Glick
- * @authos Martin Adamek
+ * @author Martin Adamek
  */
 public class MultiTargetChooserPanelGUI extends javax.swing.JPanel implements 
ActionListener, DocumentListener {
   
diff --git 
a/enterprise/j2ee.ejbcore/src/org/netbeans/modules/j2ee/ejbcore/ui/logicalview/entries/CallEjbPanel.java
 
b/enterprise/j2ee.ejbcore/src/org/netbeans/modules/j2ee/ejbcore/ui/logicalview/entries/CallEjbPanel.java
index 32d8b60e0a..4bb6beccd1 100644
--- 
a/enterprise/j2ee.ejbcore/src/org/netbeans/modules/j2ee/ejbcore/ui/logicalview/entries/CallEjbPanel.java
+++ 
b/enterprise/j2ee.ejbcore/src/org/netbeans/modules/j2ee/ejbcore/ui/logicalview/entries/CallEjbPanel.java
@@ -76,7 +76,7 @@ import org.openide.util.RequestProcessor;
  *
  * @author Chris Webster
  * @author Martin Adamek
- * @Petr Slechta
+ * @author Petr Slechta
  */
 public class CallEjbPanel extends javax.swing.JPanel {
 
diff --git 
a/enterprise/j2ee.sun.ddui/src/org/netbeans/modules/j2ee/sun/ddloaders/multiview/web/SunWebJspConfigPropertyNode.java
 
b/enterprise/j2ee.sun.ddui/src/org/netbeans/modules/j2ee/sun/ddloaders/multiview/web/SunWebJspConfigPropertyNode.java
index bc495ab2aa..c6006700ab 100644
--- 
a/enterprise/j2ee.sun.ddui/src/org/netbeans/modules/j2ee/sun/ddloaders/multiview/web/SunWebJspConfigPropertyNode.java
+++ 
b/enterprise/j2ee.sun.ddui/src/org/netbeans/modules/j2ee/sun/ddloaders/multiview/web/SunWebJspConfigPropertyNode.java
@@ -37,7 +37,7 @@ import org.openide.util.NbBundle;
 
 /**
  * @author pfiala
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public class SunWebJspConfigPropertyNode extends BaseSectionNode {
 
diff --git 
a/enterprise/j2ee.sun.ddui/src/org/netbeans/modules/j2ee/sun/share/configbean/Utils.java
 
b/enterprise/j2ee.sun.ddui/src/org/netbeans/modules/j2ee/sun/share/configbean/Utils.java
index 84d753a805..fb615fa18a 100644
--- 
a/enterprise/j2ee.sun.ddui/src/org/netbeans/modules/j2ee/sun/share/configbean/Utils.java
+++ 
b/enterprise/j2ee.sun.ddui/src/org/netbeans/modules/j2ee/sun/share/configbean/Utils.java
@@ -30,7 +30,7 @@ import org.openide.ErrorManager;
 /**
  *
  * @author vkraemer
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public class Utils implements org.netbeans.modules.j2ee.sun.share.Constants {
 
diff --git 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/Installer.java
 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/Installer.java
index 852163f9b6..77e1655591 100644
--- 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/Installer.java
+++ 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/Installer.java
@@ -24,7 +24,7 @@ import org.openide.modules.ModuleInstall;
  * Manages a module's lifecycle. Remember that an installer is optional and
  * often not needed at all.
  *
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public class Installer extends ModuleInstall {
 
diff --git 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/DisableModulesCookie.java
 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/DisableModulesCookie.java
index 902baf4f1b..60142936d9 100644
--- 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/DisableModulesCookie.java
+++ 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/DisableModulesCookie.java
@@ -29,7 +29,7 @@ import org.openide.nodes.Node;
  *
  * based on UndeployModuleCookie
  * @author Michal Mocnak
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public interface DisableModulesCookie extends Node.Cookie {
     
diff --git 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/EnableModulesCookie.java
 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/EnableModulesCookie.java
index 39355d3cae..a72a26a155 100644
--- 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/EnableModulesCookie.java
+++ 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/EnableModulesCookie.java
@@ -29,7 +29,7 @@ import org.openide.nodes.Node;
  *
  * based on UndeployModuleCookie
  * @author Michal Mocnak
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public interface EnableModulesCookie extends Node.Cookie {
     
diff --git 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/UndeployModuleCookie.java
 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/UndeployModuleCookie.java
index 148677c77a..530d9c7cf0 100644
--- 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/UndeployModuleCookie.java
+++ 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/UndeployModuleCookie.java
@@ -27,7 +27,7 @@ import org.openide.nodes.Node;
 /**
  *
  * @author Michal Mocnak
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public interface UndeployModuleCookie extends Node.Cookie {
     
diff --git 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/UnregisterResourceCookie.java
 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/UnregisterResourceCookie.java
index 101d55b5da..800c283de5 100644
--- 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/UnregisterResourceCookie.java
+++ 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/nodes/actions/UnregisterResourceCookie.java
@@ -26,7 +26,7 @@ import org.openide.nodes.Node;
 
 /**
  *
- * @auther Peter Williams
+ * @author Peter Williams
  */
 public interface UnregisterResourceCookie extends Node.Cookie {
     
diff --git 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/utils/AdminKeyFile.java
 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/utils/AdminKeyFile.java
index 7757cdb2b5..a01e9f5801 100644
--- 
a/enterprise/payara.common/src/org/netbeans/modules/payara/common/utils/AdminKeyFile.java
+++ 
b/enterprise/payara.common/src/org/netbeans/modules/payara/common/utils/AdminKeyFile.java
@@ -322,7 +322,7 @@ public class AdminKeyFile {
          * Get value of user <code>String</code> read
          * from <code>admin-keyfile</code>.
          * <p/>
-         * @rerurn Value of user <code>String</code>.
+         * @return Value of user <code>String</code>.
          */
         private String getUser() {
             return user.toString();
@@ -332,7 +332,7 @@ public class AdminKeyFile {
          * Get value of password hash <code>String</code> read
          * from <code>admin-keyfile</code>.
          * <p/>
-         * @rerurn Value of password hash <code>String</code>.
+         * @return Value of password hash <code>String</code>.
          */
         private String getPasswordHash() {
             return hash.toString();
@@ -342,7 +342,7 @@ public class AdminKeyFile {
          * Get value of tool <code>String</code> read
          * from <code>admin-keyfile</code>.
          * <p/>
-         * @rerurn Value of tool <code>String</code>.
+         * @return Value of tool <code>String</code>.
          */
         private String getTool() {
             return tool.toString();
diff --git 
a/enterprise/payara.jakartaee/src/org/netbeans/modules/payara/jakartaee/Hk2StartServer.java
 
b/enterprise/payara.jakartaee/src/org/netbeans/modules/payara/jakartaee/Hk2StartServer.java
index 9ce1805765..46b67f9d46 100644
--- 
a/enterprise/payara.jakartaee/src/org/netbeans/modules/payara/jakartaee/Hk2StartServer.java
+++ 
b/enterprise/payara.jakartaee/src/org/netbeans/modules/payara/jakartaee/Hk2StartServer.java
@@ -58,7 +58,7 @@ import org.openide.util.NbBundle;
 /**
  *
  * @author Ludovic Champenois
- * @auther Peter Williams
+ * @author Peter Williams
  * @author vince kraemer
  */
 public class Hk2StartServer extends StartServer implements ProgressObject {
diff --git 
a/enterprise/tomcat5/src/org/netbeans/modules/tomcat5/util/TomcatUsers.java 
b/enterprise/tomcat5/src/org/netbeans/modules/tomcat5/util/TomcatUsers.java
index 4e250596ad..d4216852f9 100644
--- a/enterprise/tomcat5/src/org/netbeans/modules/tomcat5/util/TomcatUsers.java
+++ b/enterprise/tomcat5/src/org/netbeans/modules/tomcat5/util/TomcatUsers.java
@@ -117,7 +117,7 @@ public class TomcatUsers {
      * 
      * @param tomcatUsersFile tomcat-users.xml file.
      * 
-     * @retun true if the user exists and has the "manager" role, false 
otherwise.
+     * @return true if the user exists and has the "manager" role, false 
otherwise.
      * 
      * @throws IOException if the file does not exist or an error occurs 
during 
      *         parsing it.
@@ -156,7 +156,7 @@ public class TomcatUsers {
      * 
      * @param tomcatUsersFile tomcat-users.xml file.
      * 
-     * @retun true if the user exists, false otherwise.
+     * @return true if the user exists, false otherwise.
      * 
      * @throws IOException if the file does not exist or an error occurs 
during 
      *         parsing it.
diff --git 
a/ide/editor.indent/src/org/netbeans/modules/editor/indent/spi/CodeStylePreferences.java
 
b/ide/editor.indent/src/org/netbeans/modules/editor/indent/spi/CodeStylePreferences.java
index f2fc570e8b..2f0164a08a 100644
--- 
a/ide/editor.indent/src/org/netbeans/modules/editor/indent/spi/CodeStylePreferences.java
+++ 
b/ide/editor.indent/src/org/netbeans/modules/editor/indent/spi/CodeStylePreferences.java
@@ -181,7 +181,7 @@ public final class CodeStylePreferences {
      * in order to seprate the project-dependent implementation of code style 
preferences
      * storage from the rest of the editor infrastructure.
      * 
-     * @Since 1.18
+     * @since 1.18
      */
     public static interface Provider {
         Preferences forFile(FileObject file, String mimeType);
diff --git a/ide/editor.lib/src/org/netbeans/editor/EditorUI.java 
b/ide/editor.lib/src/org/netbeans/editor/EditorUI.java
index d792b15be9..36a31b7e82 100644
--- a/ide/editor.lib/src/org/netbeans/editor/EditorUI.java
+++ b/ide/editor.lib/src/org/netbeans/editor/EditorUI.java
@@ -719,7 +719,7 @@ public class EditorUI implements ChangeListener, 
PropertyChangeListener, MouseLi
      * 
      * @param coloringName The name of the coloring to find.
      * 
-     * @retrun The coloring or <code>null</code> if there is no coloring with 
the
+     * @return The coloring or <code>null</code> if there is no coloring with 
the
      *   requested name.
      * @deprecated Use Editor Settings API instead.
      */
diff --git 
a/ide/editor.lib/src/org/netbeans/editor/ext/KeywordMatchGenerator.java 
b/ide/editor.lib/src/org/netbeans/editor/ext/KeywordMatchGenerator.java
index 1953809736..57cf7f7083 100644
--- a/ide/editor.lib/src/org/netbeans/editor/ext/KeywordMatchGenerator.java
+++ b/ide/editor.lib/src/org/netbeans/editor/ext/KeywordMatchGenerator.java
@@ -188,7 +188,7 @@ public class KeywordMatchGenerator {
     * called with the full range of keywords and offset equal to zero.
     * It recursively calls itself to scan the subgroups.
     * @param indFrom index in kwds[] where the subgroup of keywords starts
-    * @pararm indTo index in kwds[] where the subgroup of keywords ends
+    * @param indTo index in kwds[] where the subgroup of keywords ends
     * @param offset current horizontal offset. It's incremented as the 
subgroups
     *   are recognized. All the characters prior to offset index are the same
     *   in all keywords in the group.
diff --git a/ide/editor.lib/src/org/netbeans/editor/ext/ToolTipSupport.java 
b/ide/editor.lib/src/org/netbeans/editor/ext/ToolTipSupport.java
index 5664510290..52e279ec09 100644
--- a/ide/editor.lib/src/org/netbeans/editor/ext/ToolTipSupport.java
+++ b/ide/editor.lib/src/org/netbeans/editor/ext/ToolTipSupport.java
@@ -181,16 +181,16 @@ public class ToolTipSupport {
 
     private static final MouseListener NO_OP_MOUSE_LISTENER = new 
MouseAdapter() {};
 
-    /** @Since 2.10 */
+    /** @since 2.10 */
     public static final int FLAG_HIDE_ON_MOUSE_MOVE = 1;
-    /** @Since 2.10 */
+    /** @since 2.10 */
     public static final int FLAG_HIDE_ON_TIMER = 2;
-    /** @Since 2.10 */
+    /** @since 2.10 */
     public static final int FLAG_PERMANENT = 4;
 
-    /** @Since 2.10 */
+    /** @since 2.10 */
     public static final int FLAGS_LIGHTWEIGHT_TOOLTIP = 
FLAG_HIDE_ON_MOUSE_MOVE | FLAG_HIDE_ON_TIMER;
-    /** @Since 2.10 */
+    /** @since 2.10 */
     public static final int FLAGS_HEAVYWEIGHT_TOOLTIP = FLAG_PERMANENT;
 
     private static final String ELIPSIS = "..."; //NOI18N
@@ -297,7 +297,7 @@ public class ToolTipSupport {
     }
     
     /**
-     * @Since 2.10
+     * @since 2.10
      */
     public void setToolTip(
         JComponent toolTip,
diff --git 
a/ide/editor.settings.storage/src/org/netbeans/modules/editor/settings/storage/ProfilesTracker.java
 
b/ide/editor.settings.storage/src/org/netbeans/modules/editor/settings/storage/ProfilesTracker.java
index a7f2bb772a..ad2013f048 100644
--- 
a/ide/editor.settings.storage/src/org/netbeans/modules/editor/settings/storage/ProfilesTracker.java
+++ 
b/ide/editor.settings.storage/src/org/netbeans/modules/editor/settings/storage/ProfilesTracker.java
@@ -127,7 +127,7 @@ public final class ProfilesTracker {
      * Gets description for a profile by its name.
      * 
      * @param displayName The display name of the profile to get the 
description for.
-     * @retutn The profile's description or <code>null</code> if there is no
+     * @return The profile's description or <code>null</code> if there is no
      *   profile with the display name.
      */
     public ProfileDescription getProfileByDisplayName(String displayName) {
diff --git a/ide/languages/src/org/netbeans/api/languages/ParserManager.java 
b/ide/languages/src/org/netbeans/api/languages/ParserManager.java
index 8d994961b1..79fea8fac5 100644
--- a/ide/languages/src/org/netbeans/api/languages/ParserManager.java
+++ b/ide/languages/src/org/netbeans/api/languages/ParserManager.java
@@ -71,7 +71,7 @@ public abstract class ParserManager {
     /**
      * Returns state of parser.
      * 
-     * @retrun a state of parser
+     * @return a state of parser
      */
     public abstract State getState ();
     
@@ -79,7 +79,7 @@ public abstract class ParserManager {
      * Returns AST tree root node.
      * 
      * @throws in the case of errors in document
-     * @retrun AST tree root node
+     * @return AST tree root node
      */
     public abstract ASTNode getAST () throws ParseException;
     
diff --git a/ide/o.openidex.util/src/org/openidex/search/SearchGroup.java 
b/ide/o.openidex.util/src/org/openidex/search/SearchGroup.java
index 1a3f75a3af..98373d7aae 100644
--- a/ide/o.openidex.util/src/org/openidex/search/SearchGroup.java
+++ b/ide/o.openidex.util/src/org/openidex/search/SearchGroup.java
@@ -161,7 +161,7 @@ public abstract class SearchGroup {
     /**
      * Does search.
      *
-     * @throw RuntimeException USER level annotated runtime exception
+     * @throws RuntimeException USER level annotated runtime exception
      *        on low memory condition (instead of OutOfMemoryError)
      */
     public void search() {
diff --git 
a/ide/xml.schema.completion/src/org/netbeans/modules/xml/schema/completion/EndTagResultItem.java
 
b/ide/xml.schema.completion/src/org/netbeans/modules/xml/schema/completion/EndTagResultItem.java
index 7d9f9fd7e3..e954186a20 100644
--- 
a/ide/xml.schema.completion/src/org/netbeans/modules/xml/schema/completion/EndTagResultItem.java
+++ 
b/ide/xml.schema.completion/src/org/netbeans/modules/xml/schema/completion/EndTagResultItem.java
@@ -34,7 +34,7 @@ import org.openide.util.NbBundle;
 
 /**
  *
- * @Alex Petrov ([email protected])
+ * @author Alex Petrov ([email protected])
  */
 public class EndTagResultItem extends CompletionResultItem {
     private static final Logger _logger = 
Logger.getLogger(EndTagResultItem.class.getName());
diff --git 
a/ide/xml.schema.completion/src/org/netbeans/modules/xml/schema/completion/TagLastCharResultItem.java
 
b/ide/xml.schema.completion/src/org/netbeans/modules/xml/schema/completion/TagLastCharResultItem.java
index 0e90fc624a..43a50178f9 100644
--- 
a/ide/xml.schema.completion/src/org/netbeans/modules/xml/schema/completion/TagLastCharResultItem.java
+++ 
b/ide/xml.schema.completion/src/org/netbeans/modules/xml/schema/completion/TagLastCharResultItem.java
@@ -28,7 +28,7 @@ import 
org.netbeans.modules.xml.schema.completion.util.CompletionUtil;
 
 /**
  *
- * @Alex Petrov ([email protected])
+ * @author Alex Petrov ([email protected])
  */
 public class TagLastCharResultItem extends CompletionResultItem {
     private static final Logger _logger = 
Logger.getLogger(TagLastCharResultItem.class.getName());
diff --git 
a/ide/xml.schema.model/test/unit/src/org/netbeans/modules/xml/schema/model/impl/AnnotationImplTest.java
 
b/ide/xml.schema.model/test/unit/src/org/netbeans/modules/xml/schema/model/impl/AnnotationImplTest.java
index 80e4c89b6a..196a7d9818 100644
--- 
a/ide/xml.schema.model/test/unit/src/org/netbeans/modules/xml/schema/model/impl/AnnotationImplTest.java
+++ 
b/ide/xml.schema.model/test/unit/src/org/netbeans/modules/xml/schema/model/impl/AnnotationImplTest.java
@@ -48,7 +48,7 @@ import org.netbeans.modules.xml.xdm.nodes.Text;
 import org.w3c.dom.Element;
 
 /**
- * @auther Nam Nguyen
+ * @author Nam Nguyen
  * @author Vidhya Narayanan
  */
 public class AnnotationImplTest extends TestCase {
diff --git 
a/ide/xml.text/src/org/netbeans/modules/xml/text/api/XMLTextUtils.java 
b/ide/xml.text/src/org/netbeans/modules/xml/text/api/XMLTextUtils.java
index bacc4f6c3e..4daa51f0c2 100644
--- a/ide/xml.text/src/org/netbeans/modules/xml/text/api/XMLTextUtils.java
+++ b/ide/xml.text/src/org/netbeans/modules/xml/text/api/XMLTextUtils.java
@@ -164,7 +164,7 @@ public final class XMLTextUtils {
      * @param doc
      * @param startOffset
      * @param endOffset 
-     * @throw IllegalArgumentException if the document implementation is not 
compatible
+     * @throws IllegalArgumentException if the document implementation is not 
compatible
      */
     public static void reformat(final LineDocument doc, final int startOffset, 
final int endOffset) {
         final XMLLexerFormatter formatter = new XMLLexerFormatter(null);
diff --git 
a/ide/xml.text/src/org/netbeans/modules/xml/text/api/dom/SyntaxElement.java 
b/ide/xml.text/src/org/netbeans/modules/xml/text/api/dom/SyntaxElement.java
index 3620eb9210..839fc2d845 100644
--- a/ide/xml.text/src/org/netbeans/modules/xml/text/api/dom/SyntaxElement.java
+++ b/ide/xml.text/src/org/netbeans/modules/xml/text/api/dom/SyntaxElement.java
@@ -43,7 +43,7 @@ import org.w3c.dom.Node;
  * {@code SyntaxElement} to a {@link TagElement} and use extended interface.
  * 
  * @author sdedic
- * @sice 1.60
+ * @since 1.60
  */
 public interface SyntaxElement {
     /**
diff --git 
a/ide/xml.wsdl.model/src/org/netbeans/modules/xml/wsdl/model/extensions/soap/impl/SOAPElementFactoryProvider.java
 
b/ide/xml.wsdl.model/src/org/netbeans/modules/xml/wsdl/model/extensions/soap/impl/SOAPElementFactoryProvider.java
index 761aa02d9e..c1f4cce4df 100644
--- 
a/ide/xml.wsdl.model/src/org/netbeans/modules/xml/wsdl/model/extensions/soap/impl/SOAPElementFactoryProvider.java
+++ 
b/ide/xml.wsdl.model/src/org/netbeans/modules/xml/wsdl/model/extensions/soap/impl/SOAPElementFactoryProvider.java
@@ -28,7 +28,7 @@ import org.netbeans.modules.xml.wsdl.model.spi.ElementFactory;
 import org.w3c.dom.Element;
 
 /**
- * @authro Nam Nguyen
+ * @author Nam Nguyen
  * @author rico
  */
 public class SOAPElementFactoryProvider {
diff --git 
a/java/form/src/org/netbeans/modules/form/layoutsupport/AbstractLayoutSupport.java
 
b/java/form/src/org/netbeans/modules/form/layoutsupport/AbstractLayoutSupport.java
index b418b25aea..b9a69f630b 100644
--- 
a/java/form/src/org/netbeans/modules/form/layoutsupport/AbstractLayoutSupport.java
+++ 
b/java/form/src/org/netbeans/modules/form/layoutsupport/AbstractLayoutSupport.java
@@ -745,7 +745,7 @@ public abstract class AbstractLayoutSupport implements 
LayoutSupportDelegate
     /**
      * Returns context for the assistant (context sensitive help bar).
      *
-     * @rerurn context for the assistant.
+     * @return context for the assistant.
      */
     public String getAssistantContext() {
         return null;
diff --git 
a/java/form/src/org/netbeans/modules/form/layoutsupport/LayoutSupportManager.java
 
b/java/form/src/org/netbeans/modules/form/layoutsupport/LayoutSupportManager.java
index 0d3dd9e4c9..e0393142ab 100644
--- 
a/java/form/src/org/netbeans/modules/form/layoutsupport/LayoutSupportManager.java
+++ 
b/java/form/src/org/netbeans/modules/form/layoutsupport/LayoutSupportManager.java
@@ -79,7 +79,7 @@ public final class LayoutSupportManager implements 
LayoutSupportContext {
     /**
      * Creation and initialization of a layout delegate for a new container.
      * @return false if suitable layout delegate is not found
-     * @throw IllegalArgumentException if the container instance is not empty
+     * @throws IllegalArgumentException if the container instance is not empty
      */
     public boolean prepareLayoutDelegate(boolean fromCode, boolean initialize)
         throws Exception
diff --git 
a/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/provider/ProviderUtil.java
 
b/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/provider/ProviderUtil.java
index cfcd17c3bd..4deda3ec88 100644
--- 
a/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/provider/ProviderUtil.java
+++ 
b/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/provider/ProviderUtil.java
@@ -161,7 +161,7 @@ public class ProviderUtil {
      * @param pu the persistence unit whose database connection is to 
      * be retrieved; must not be null.
      * 
-     * @rerturn the connection specified in the given persistence unit or
+     * @return the connection specified in the given persistence unit or
      * <code>null</code> if it didn't specify a connectioh.
      * 
      */
@@ -212,7 +212,7 @@ public class ProviderUtil {
      * @param pu the persistence unit whose database connection is to 
      * be retrieved; must not be null.
      * 
-     * @rerturn the connection properties specified in the given persistence 
unit or
+     * @return the connection properties specified in the given persistence 
unit or
      * <code>null</code> if it didn't specify a connectioh.
      * 
      */
diff --git 
a/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterArrayInitOrEnumUnitTest.java
 
b/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterArrayInitOrEnumUnitTest.java
index 7851ec5008..6c741bc9c8 100644
--- 
a/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterArrayInitOrEnumUnitTest.java
+++ 
b/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterArrayInitOrEnumUnitTest.java
@@ -36,7 +36,7 @@ import org.openide.util.Lookup;
 /**
  * Java formatter tests.
  *
- * @autor Miloslav Metelka
+ * @author Miloslav Metelka
  */
 public class JavaFormatterArrayInitOrEnumUnitTest extends 
JavaFormatterUnitTestCase {
 
diff --git 
a/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterUnitTest.java
 
b/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterUnitTest.java
index 6a67d7b790..e549cc5b4b 100644
--- 
a/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterUnitTest.java
+++ 
b/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterUnitTest.java
@@ -38,7 +38,7 @@ import org.openide.util.Lookup;
 /**
  * Java formatter tests.
  *
- * @autor Miloslav Metelka
+ * @author Miloslav Metelka
  */
 public class JavaFormatterUnitTest extends JavaFormatterUnitTestCase {
 
diff --git 
a/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterUnitTestCase.java
 
b/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterUnitTestCase.java
index fc3addd033..02c89f9a1a 100644
--- 
a/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterUnitTestCase.java
+++ 
b/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/JavaFormatterUnitTestCase.java
@@ -27,7 +27,7 @@ import org.netbeans.modules.editor.indent.api.Reformat;
 /**
  * Java formatter tests.
  *
- * @autor Miloslav Metelka
+ * @author Miloslav Metelka
  */
 public class JavaFormatterUnitTestCase extends JavaBaseDocumentUnitTestCase {
 
diff --git 
a/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/TestUtils.java
 
b/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/TestUtils.java
index 5ab543efef..75059ab227 100644
--- 
a/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/TestUtils.java
+++ 
b/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/TestUtils.java
@@ -36,7 +36,7 @@ import org.openide.filesystems.Repository;
  * Call setupData() in test's setUp() and cleanupData() in test's tearDown().
  * Then you can you rest of the utility methods.
  *
- * @autor David Konecny
+ * @author David Konecny
  */
 public final class TestUtils {
     
diff --git 
a/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/TypingCompletionUnitTest.java
 
b/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/TypingCompletionUnitTest.java
index fa87409d73..9002f7e7b9 100644
--- 
a/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/TypingCompletionUnitTest.java
+++ 
b/java/java.editor/test/unit/src/org/netbeans/modules/editor/java/TypingCompletionUnitTest.java
@@ -47,7 +47,7 @@ import org.openide.util.lookup.ServiceProvider;
  * Test java brackets completion - unlike the original test this one
  * emulates real typing and tests the resulting state of the document.
  *
- * @autor Miloslav Metelka
+ * @author Miloslav Metelka
  */
 public class TypingCompletionUnitTest extends NbTestCase {
 
diff --git 
a/java/java.freeform/src/org/netbeans/modules/java/freeform/JavaActions.java 
b/java/java.freeform/src/org/netbeans/modules/java/freeform/JavaActions.java
index f6f794ccf5..9baa9a5dfc 100644
--- a/java/java.freeform/src/org/netbeans/modules/java/freeform/JavaActions.java
+++ b/java/java.freeform/src/org/netbeans/modules/java/freeform/JavaActions.java
@@ -672,7 +672,7 @@ final class JavaActions implements ActionProvider {
      * Use with {@link #GENERAL_SCRIPT_PATH}.
      * Idempotent, takes effect only once.
      * @param antProject XML of an Ant project (document element)
-     * @oaram origScriptPath Ant name of original build script's path
+     * @param origScriptPath Ant name of original build script's path
      */
     void ensureImports(Element antProject, String origScriptPath) throws 
IOException, SAXException {
         if (antProject.getAttribute("basedir").length() > 0) {
diff --git 
a/java/java.source.base/src/org/netbeans/modules/java/source/parsing/JavacParser.java
 
b/java/java.source.base/src/org/netbeans/modules/java/source/parsing/JavacParser.java
index e7ea29530d..b74013131c 100644
--- 
a/java/java.source.base/src/org/netbeans/modules/java/source/parsing/JavacParser.java
+++ 
b/java/java.source.base/src/org/netbeans/modules/java/source/parsing/JavacParser.java
@@ -620,7 +620,7 @@ public class JavacParser extends Parser {
      * Moves the Javac into the required {@link JavaSource#Phase}
      * Not synchronized, has to be called under Parsing API lock.
      * @param the required {@link JavaSource#Phase}
-     * @parma currentInfo - the javac
+     * @param currentInfo - the javac
      * @param cancellable when true the method checks cancels
      * @return the reached phase
      * @throws IOException when the javac throws an exception
diff --git 
a/nbi/engine/src/org/netbeans/installer/wizard/containers/SwingFrameContainer.java
 
b/nbi/engine/src/org/netbeans/installer/wizard/containers/SwingFrameContainer.java
index a7be243555..9fc28dd530 100644
--- 
a/nbi/engine/src/org/netbeans/installer/wizard/containers/SwingFrameContainer.java
+++ 
b/nbi/engine/src/org/netbeans/installer/wizard/containers/SwingFrameContainer.java
@@ -64,7 +64,7 @@ import org.netbeans.installer.wizard.ui.WizardUi;
  * In this case the container is an {@link NbiFrame}.
  *
  * @author Kirill Sorokin
- * @sicne 1.0
+ * @since 1.0
  */
 public class SwingFrameContainer extends NbiFrame implements SwingContainer {
     
/////////////////////////////////////////////////////////////////////////////////
diff --git 
a/php/php.api.framework/src/org/netbeans/modules/php/api/framework/BadgeIcon.java
 
b/php/php.api.framework/src/org/netbeans/modules/php/api/framework/BadgeIcon.java
index 09411ece51..8f06c5821f 100644
--- 
a/php/php.api.framework/src/org/netbeans/modules/php/api/framework/BadgeIcon.java
+++ 
b/php/php.api.framework/src/org/netbeans/modules/php/api/framework/BadgeIcon.java
@@ -37,7 +37,7 @@ public final class BadgeIcon {
      * Creates a new badge icon. Image has to have 8x8 dimensions.
      * @param image image of icon
      * @param url URL of icon
-     * @thows IllegalArgumentException if the width or height is not 8 pixels 
(under assertions only)
+     * @throws IllegalArgumentException if the width or height is not 8 pixels 
(under assertions only)
      */
     public BadgeIcon(Image image, URL url) {
         Parameters.notNull("image", image); // NOI18N
diff --git 
a/platform/core.kit/test/perf/src/org/openide/filesystems/localfs/LocalFSTest.java
 
b/platform/core.kit/test/perf/src/org/openide/filesystems/localfs/LocalFSTest.java
index 8edd4497b4..a43314f970 100644
--- 
a/platform/core.kit/test/perf/src/org/openide/filesystems/localfs/LocalFSTest.java
+++ 
b/platform/core.kit/test/perf/src/org/openide/filesystems/localfs/LocalFSTest.java
@@ -82,7 +82,7 @@ public class LocalFSTest extends FSTest implements 
DataManager {
     
     /** Creates a given number of files in a given folder (actually in a 
subfolder)
      * @param 
-     * @retun a folder in which reside the created files (it is a sub folder 
of destRoot)
+     * @return a folder in which reside the created files (it is a sub folder 
of destRoot)
      */
     public static File createFiles(int foCount, int foBase, File destRoot) 
throws Exception {
         InputStream is = 
LocalFSTest.class.getClassLoader().getResourceAsStream(getResource(0));
diff --git a/platform/o.n.bootstrap/src/org/netbeans/NetigsoFramework.java 
b/platform/o.n.bootstrap/src/org/netbeans/NetigsoFramework.java
index 34ec518b70..b03a22f22b 100644
--- a/platform/o.n.bootstrap/src/org/netbeans/NetigsoFramework.java
+++ b/platform/o.n.bootstrap/src/org/netbeans/NetigsoFramework.java
@@ -82,7 +82,7 @@ public abstract class NetigsoFramework {
     protected abstract void shutdown();
 
     /** Initializes a classloader for given module.
-     * @parma m the module description
+     * @param m the module description
      * @param pcl proxy classloader that shall be configured
      * @param jar the module JAR file
      * @return set of covered packages
@@ -139,7 +139,7 @@ public abstract class NetigsoFramework {
      * method to store it for next time.
      *
      * @param name name of the resource inside the JAR
-     * @parma resources the provider of the real resources
+     * @param resources the provider of the real resources
      * @return either cached value or the one returned by resources (or null)
      * @throws IOException if something goes wrong
      * @since 2.29
diff --git 
a/platform/openide.loaders/src/org/openide/loaders/XMLEntityResolverChain.java 
b/platform/openide.loaders/src/org/openide/loaders/XMLEntityResolverChain.java
index 9cd2113666..8a23e8e8d2 100644
--- 
a/platform/openide.loaders/src/org/openide/loaders/XMLEntityResolverChain.java
+++ 
b/platform/openide.loaders/src/org/openide/loaders/XMLEntityResolverChain.java
@@ -85,8 +85,8 @@ final class XMLEntityResolverChain implements EntityResolver {
      *        or null if none was supplied.
      * @param systemID - The system identifier of the external entity being 
referenced.
      *
-     * @throw SAXException - Any SAX exception, possibly wrapping another 
exception. 
-     * @throw IOException - A Java-specific IO exception, possibly the result 
of creating 
+     * @throws SAXException - Any SAX exception, possibly wrapping another 
exception.
+     * @throws IOException - A Java-specific IO exception, possibly the result 
of creating
      *        a new InputStream or Reader for the InputSource.
      *
      * @return An InputSource object describing the new input source, 
diff --git a/platform/openide.util/src/org/openide/xml/XMLUtil.java 
b/platform/openide.util/src/org/openide/xml/XMLUtil.java
index c7d643245c..19e517e78b 100644
--- a/platform/openide.util/src/org/openide/xml/XMLUtil.java
+++ b/platform/openide.util/src/org/openide/xml/XMLUtil.java
@@ -189,8 +189,8 @@ public final class XMLUtil extends Object {
      * Obtains DOMImpementaton interface providing a number of methods for 
performing
      * operations that are independent of any particular DOM instance.
      *
-     * @throw DOMException <code>NOT_SUPPORTED_ERR</code> if cannot get 
DOMImplementation
-     * @throw FactoryConfigurationError Application developers should never 
need to directly catch errors of this type.
+     * @throws DOMException <code>NOT_SUPPORTED_ERR</code> if cannot get 
DOMImplementation
+     * @throws FactoryConfigurationError Application developers should never 
need to directly catch errors of this type.
      *
      * @return DOMImplementation implementation
      */
diff --git 
a/ide/csl.api/src/org/netbeans/modules/csl/spi/DefaultLanguageConfig.java 
b/ide/csl.api/src/org/netbeans/modules/csl/spi/DefaultLanguageConfig.java
index a79a67bf3e..021b94c82b 100644
--- a/ide/csl.api/src/org/netbeans/modules/csl/spi/DefaultLanguageConfig.java
+++ b/ide/csl.api/src/org/netbeans/modules/csl/spi/DefaultLanguageConfig.java
@@ -111,7 +111,7 @@ public abstract class DefaultLanguageConfig implements 
GsfLanguage {
      * NOTE: Code folding doesn't work until you enable code folding for your
      * editor kit; see GsfEditorKitFactory's reference to CODE_FOLDING_ENABLE 
for
      * an example.
      * @wasdeprecated This function is not called anymore. You
      *  MUST register the custom editor kit attribute via the layer! That's 
because
      *  currently, finding out whether a module has supplies a custom editor
      *  kit must be done early during startup (in the file type recognition 
code,
@@ -120,6 +120,7 @@ public abstract class DefaultLanguageConfig implements 
GsfLanguage {
      *  (including classes they reference) at startup. Hopefully a
      *  better solution will be provided soon.
      */
+    @Deprecated
     public boolean isUsingCustomEditorKit() {
         return false;
     }
@@ -195,7 +196,7 @@ public abstract class DefaultLanguageConfig implements 
GsfLanguage {
      * 
      * @return true iff this language configuration provides a
      *  structure scanner.
      * @wasdeprecated This function is not called anymore. You
      *  MUST register structure scanners via the layer! That's because
      *  currently, finding out whether a module has a structure scanner
      *  has to be done very early (before any language types are opened)
@@ -203,6 +204,7 @@ public abstract class DefaultLanguageConfig implements 
GsfLanguage {
      *  (including classes they reference) at startup. Hopefully a
      *  better solution will be provided soon.
      */
+    @Deprecated
     public boolean hasStructureScanner() {
         return false;
     }
@@ -111,7 +111,7 @@ public abstract class DefaultLanguageConfig implements 
for
      * an example.
-     * @wasdeprecated This function is not called anymore. You
+     * @deprecated This function is not called anymore. You
      *  MUST register the custom editor kit attribute via the layer! That's 
because
@@ -195,7 +196,7 @@ public abstract class DefaultLanguageConfig implements 
      * @return true iff this language configuration provides a
      *  structure scanner.
-     * @wasdeprecated This function is not called anymore. You
+     * @deprecated This function is not called anymore. You
      *  MUST register structure scanners via the layer! That's because
      *  currently, finding out whether a module has a structure scanner
diff --git a/ide/editor.lib/src/org/netbeans/editor/JumpList.java 
b/ide/editor.lib/src/org/netbeans/editor/JumpList.java
index 4dae95990d..2654846130 100644
--- a/ide/editor.lib/src/org/netbeans/editor/JumpList.java
+++ b/ide/editor.lib/src/org/netbeans/editor/JumpList.java
@@ -210,8 +210,9 @@ public final class JumpList {
 
     /**
      * @return Unspecified string.
      * @deprecate Should have never been public.
      */
+    @Deprecated
     public static String dump() {
         StringBuilder sb = new StringBuilder();
         
@@ -210,8 +210,9 @@ public final class JumpList {
     /**
      * @return Unspecified string.
-     * @deprecate Should have never been public.
+     * @deprecated Should have never been public.
      */
diff --git 
a/platform/spi.quicksearch/src/org/netbeans/modules/quicksearch/recent/RecentSearches.java
 
b/platform/spi.quicksearch/src/org/netbeans/modules/quicksearch/recent/RecentSearches.java
index 5e65a70f1d..b7cb2b63d5 100644
--- 
a/platform/spi.quicksearch/src/org/netbeans/modules/quicksearch/recent/RecentSearches.java
+++ 
b/platform/spi.quicksearch/src/org/netbeans/modules/quicksearch/recent/RecentSearches.java
@@ -51,7 +51,7 @@ import org.openide.util.Task;
  * Recent Searches items storage and its persistance
  *
  * @author Jan Becicka
- * @authoe Max Sauer
+ * @author Max Sauer
  */
 public class RecentSearches {
     
diff --git 
a/webcommon/web.clientproject.api/src/org/netbeans/modules/web/clientproject/api/BadgeIcon.java
 
b/webcommon/web.clientproject.api/src/org/netbeans/modules/web/clientproject/api/BadgeIcon.java
index b6db64cd08..a774e1611a 100644
--- 
a/webcommon/web.clientproject.api/src/org/netbeans/modules/web/clientproject/api/BadgeIcon.java
+++ 
b/webcommon/web.clientproject.api/src/org/netbeans/modules/web/clientproject/api/BadgeIcon.java
@@ -39,7 +39,7 @@ public final class BadgeIcon {
      * Creates a new badge icon. Image has to have 8x8 dimensions.
      * @param image image of icon
      * @param url URL of icon
-     * @thows IllegalArgumentException if the width or height is not 8 pixels 
(under assertions only)
+     * @throws IllegalArgumentException if the width or height is not 8 pixels 
(under assertions only)
      */
     public BadgeIcon(Image image, URL url) {
         Parameters.notNull("image", image); // NOI18N
diff --git 
a/websvccommon/websvc.saas.api/src/org/netbeans/modules/websvc/saas/model/Saas.java
 
b/websvccommon/websvc.saas.api/src/org/netbeans/modules/websvc/saas/model/Saas.java
index eb0034f1fb..5610eab8e2 100644
--- 
a/websvccommon/websvc.saas.api/src/org/netbeans/modules/websvc/saas/model/Saas.java
+++ 
b/websvccommon/websvc.saas.api/src/org/netbeans/modules/websvc/saas/model/Saas.java
@@ -324,7 +324,7 @@ public class Saas implements Comparable<Saas> {
     }
 
     /**
-     * @eturns absolute paths to all library jars, generated or 
+     * @return absolute paths to all library jars, generated or
      * provided by vendor module.  Generated
      */
     public List<FileObject> getLibraryJars() {


---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

For further information about the NetBeans mailing lists, visit:
https://cwiki.apache.org/confluence/display/NETBEANS/Mailing+lists

Reply via email to